﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'uk', {
	auto: 'Авто',
	bgColorTitle: 'Колір фону',
	colors: {
		'000': 'Чорний',
		'800000': 'Бордовий',
		'8B4513': 'Коричневий',
		'2F4F4F': 'Темний сіро-зелений',
		'008080': 'Морської хвилі',
		'000080': 'Сливовий',
		'4B0082': 'Індиго',
		'696969': 'Темно-сірий',
		B22222: 'Темночервоний',
		A52A2A: 'Каштановий',
		DAA520: 'Бежевий',
		'006400': 'Темно-зелений',
		'40E0D0': 'Бірюзовий',
		'0000CD': 'Темносиній',
		'800080': 'Пурпурний',
		'808080': 'Сірий',
		F00: 'Червоний',
		FF8C00: 'Темно-помаранчевий',
		FFD700: 'Жовтий',
		'008000': 'Зелений',
		'0FF': 'Синьо-зелений',
		'00F': 'Синій',
		EE82EE: 'Фіолетовий',
		A9A9A9: 'Тьмяно-сірий',
		FFA07A: 'Рожевий',
		FFA500: 'Помаранчевий',
		FFFF00: 'Яскравожовтий',
		'00FF00': 'Салатовий',
		AFEEEE: 'Світлобірюзовий',
		ADD8E6: 'Блакитний',
		DDA0DD: 'Світлофіолетовий',
		D3D3D3: 'Світло-сірий',
		FFF0F5: 'Світлорожевий',
		FAEBD7: 'Світлооранжевий',
		FFFFE0: 'Світло-жовтий',
		F0FFF0: 'Світлозелений',
		F0FFFF: 'Світлий синьо-зелений',
		F0F8FF: 'Світлоблакитний',
		E6E6FA: 'Лавандовий',
		FFF: 'Білий',
		'1ABC9C': 'Насичений блакитний',
		'2ECC71': 'Смарагдовий',
		'3498DB': 'Яскраво-синій',
		'9B59B6': 'Аметистовий',
		'4E5F70': 'Сірувато-синій',
		'F1C40F': 'Яскраво-жовтий',
		'16A085': 'Темно-блакитний',
		'27AE60': 'Темно-смарагдовий',
		'2980B9': 'Насичений синій',
		'8E44AD': 'Темно-фіолетовий',
		'2C3E50': 'Ненасичений синій',
		'F39C12': 'Помаранчевий',
		'E67E22': 'Морквяний',
		'E74C3C': 'Блідо-червоний',
		'ECF0F1': 'Яскраво-сріблястий',
		'95A5A6': 'Світлий сірувато-блакитний',
		'DDD': 'Світло-сірий',
		'D35400': 'Гарбузовий',
		'C0392B': 'Насичений червоний',
		'BDC3C7': 'Сріблястий',
		'7F8C8D': 'Сірувато-блакитний',
		'999': 'Темно-сірий'
	},
	more: 'Кольори...',
	panelTitle: 'Кольори',
	textColorTitle: 'Колір тексту'
} );
